package it.univr.prog.bioinfo.pizzeria;

import java.util.List;

/**
 * Classe oggetto che rappresenta una pizza.
 * 
 * @author Damiano Macedonio
 * @version 2.0
 */

public class Pizza {

	/**
	 * Nome della pizza.
	 */
	private String nome;

	/**
	 * Lista degli ingredienti che costituiscono la pizza.
	 */
	private List<Ingrediente> ingredienti;

	/**
	 * Crea un nuovo oggetto Pizza con parametri impostati dall'utente.
	 * 
	 * @param nome
	 *            nome della pizza
	 * @param ingredienti
	 *            lista degli ingredienti
	 */
	public Pizza(String nome, List<Ingrediente> ingredienti) {
		this.nome = nome;
		this.ingredienti = ingredienti;

	}

	/**
	 * Ritorna il nome della pizza.
	 * 
	 * @return nome della pizza
	 */
	public String getNome() {
		return nome;
	}

	/**
	 * Ritorna il prezzo della pizza.
	 * 
	 * @return prezzo della pizza
	 */
	public double getPrezzo() {
		double prezzo = .0;
		for (Ingrediente i : this.ingredienti)
			prezzo += i.getPrezzo();
		return prezzo;
	}

	/**
	 * Ritorna una descrizione testuale della pizza.
	 * 
	 * @return descrizione testuale della pizza
	 */
	public String toString() {
		String str = "";
		str = "Pizza: " + this.nome + "\n";
		for (Ingrediente i : ingredienti)
			str += "\t\t" + i.getNome() + "\n";
		str += "Prezzo: " + this.getPrezzo();
		return str;
	}

}